spawn_blocking

Function spawn_blocking 

pub fn spawn_blocking<F, R>(blocking_func: F) -> JoinHandle<R> 
where F: FnOnce() -> R + 'static, R: 'static,
Spawns a blocking task by wrapping the blocking function in an async block. In WASM this is equivalent to spawn_local since true blocking cannot be offloaded to another thread.