Sleep

Struct Sleep 

pub struct Sleep { /* private fields */ }

Implementations

Source

impl Sleep

pub fn deadline(&self) -> Instant

Returns the instant at which the future will complete.

pub fn is_elapsed(&self) -> bool

Returns true if Sleep has elapsed

A Sleep instance is elapsed when the requested duration has elapsed

pub fn reset(self: Pin<&mut Sleep>, deadline: Instant)

Resets this timeout to an new timeout which will fire at the time specified by dur.

This method is usable even of this instance of Delay has “already fired”. That is, if this future has resovled, calling this method means that the future will still re-resolve at the specified instant.

If at is in the past then this future will immediately be resolved (when poll is called).

Note that if any task is currently blocked on this future then that task will be dropped. It is required to call poll again after this method has been called to ensure tha ta task is blocked on this future.